package com.srs.comprehensive.service;

import com.srs.comprehensive.domain.SrsCeScore;
import com.srs.comprehensive.domain.Vo.SrsCeScoreStudent;
import com.srs.comprehensive.domain.Vo.SrsCeScoreStudentStuYear;

import java.util.List;

/**
 * 综合评价Service接口
 * 
 * @author srs
 * @date 2023-06-28
 */
public interface ISrsCeScoreService 
{
    /**
     * 查询综合评价
     * 
     * @param id 综合评价主键
     * @return 综合评价
     */
    public SrsCeScore selectSrsCeScoreById(Long id);

    /**
     * 查询综合评价列表
     * 
     * @param srsCeScore 综合评价
     * @return 综合评价集合
     */
    public List<SrsCeScore> selectSrsCeScoreList(SrsCeScore srsCeScore);

    /**
     * 新增综合评价
     * 
     * @param srsCeScore 综合评价
     * @return 结果
     */
    public int insertSrsCeScore(SrsCeScore srsCeScore);

    /**
     * 修改综合评价
     * 
     * @param srsCeScore 综合评价
     * @return 结果
     */
    public int updateSrsCeScore(SrsCeScore srsCeScore);

    /**
     * 批量删除综合评价
     * 
     * @param ids 需要删除的综合评价主键集合
     * @return 结果
     */
    public int deleteSrsCeScoreByIds(Long[] ids);

    /**
     * 删除综合评价信息
     * 
     * @param id 综合评价主键
     * @return 结果
     */
    public int deleteSrsCeScoreById(Long id);
    /**
     *综合评价连表查询
     * @return 结果
     */
    List<SrsCeScoreStudentStuYear> SrsCeScoreStudentStuYear(SrsCeScore srsCeScore);
    /**
     * 综合评价成绩导入
     */
    int insertSrsCeScoreStudent(List<SrsCeScoreStudent> srsCeScoreStudents);
}
